@@ -77,6 +77,8 @@ sub _connect {
 	$socket->connect;
 
 	my $ws_client = Protocol::WebSocket::Client->new(url => $self->{info}->{url});
+	$ws_client->{hs}->req->{max_message_size} = $self->{options}->{max_message_size} if $self->{options}->{max_message_size};
+	$ws_client->{hs}->res->{max_message_size} = $self->{options}->{max_message_size} if $self->{options}->{max_message_size};
 	$ws_client->on(read => sub {
 			my ($cli, $buffer) = @_;
 			$self->_listen($buffer);
@@ -98,14 +100,6 @@ sub _connect {
 	$self->{socket} = $socket;
 }
 
-sub reconnect {
-	my $self = shift;
-	unless ($self->{socket}->opened) {
-		print "reconecting...\n" if ($self->{options}->{debug});
-		$self->_connect;
-	}
-}
-
 sub disconnect {
 	my $self = shift;
 	$self->{ws_client}->disconnect;
